import { useCallback, useState } from "preact/hooks";
import { DataRow } from "../api/DataRow";
import style from './index.module.scss';
import { Posts } from "../components/Posts";

import InfiniteScroller from 'react-infinite-scroller';

// let page = -1;

export function Index() {
    const [ data, setData ] = useState(null as null | DataRow[]);
    const [ selected, setSelected ] = useState(null as null | DataRow[]);

    const [ hasMore, setHasMore ] = useState(true);
    const [ fetching, setFetching ] = useState(false);

    const fetchMore = useCallback(
        async function(_page: number) {
            if (fetching) return;

            setFetching(true);
            await new Promise(r => setTimeout(r, 1000));
            const newData = await DataRow.find({
                page: data ? Math.floor(data.length / 20) : 0
            });
            setData([ ...data ?? [], ...newData ]);
            setHasMore(newData.length === 20);
            setFetching(false);
        },
        [ fetching, hasMore ]
    );

    function select(row: DataRow) {
        console.log(row);
        if (data) {
            if (data.indexOf(row) == -1) throw new Error('Selected element that does not exist');
            setSelected([ ...selected ?? [], row ])
            setData(data)
        }
    }

    return (
        <div className={style.index}>
            
            {
                selected
                    ?
                        <div className={style.selection}>
                            <h2>Selection</h2>
                            <Posts rows={selected} checked />
                        </div>
                    : null
            }
            
            <InfiniteScroller
                pageStart={0}
                loadMore={fetchMore}
                hasMore={hasMore}
                loader={<pre>loading . . .</pre>}
                useWindow={false}
                >
                {
                    data
                        ? <Posts rows={data.filter(x => selected ? selected?.indexOf(x) === -1 : true)} onSelectChange={select} />
                        : <></>
                }
            </InfiniteScroller>
        </div>
    )
}